==> vue-icon-saas-2.8.0.tgz: package/lib/rich-text-table.js <==
import { svg } from "@dft-vue-2-opentiny/vue-common";
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("svg", _vm._g({
    attrs: {
      "viewBox": "0 0 1024 1024",
      "xmlns": "http://www.w3.org/2000/svg",
      "width": "24",
      "height": "24"
    }
  }, _vm.$listeners), [_c("path", {
    attrs: {
      "d": "M885.3 957.3H140.7c-42.2 0-76.5-34.3-76.5-76.5V136.3c0-42.2 34.3-76.5 76.5-76.5h744.6c42.2 0 76.5 34.3 76.5 76.5v744.6c-.1 42.1-34.3 76.4-76.5 76.4zm-744.6-851c-16.5 0-29.9 13.4-29.9 29.9v744.6c0 16.5 13.4 29.9 29.9 29.9h744.6c16.5 0 29.9-13.4 29.9-29.9V136.3c0-16.5-13.4-29.9-29.9-29.9H140.7z",
      "fill": "#2c2c2c"
    }
  }), _c("path", {
    attrs: {
      "d": "M938.5 315.8h-851V91.1c0-4.4 3.6-8 8-8h835c4.4 0 8 3.6 8 8v224.7z",
      "fill": "#2c2c2c"
    }
  }), _c("path", {
    attrs: {
      "d": "M961.7 339H64.3V136.3c0-42.2 34.3-76.5 76.5-76.5h744.6c42.2 0 76.5 34.3 76.5 76.5V339zm-850.9-46.5h804.4V136.3c0-16.5-13.4-29.9-29.9-29.9H140.7c-16.5 0-29.9 13.4-29.9 29.9v156.2zm827.7 352.3h-851c-12.9 0-23.3-10.4-23.3-23.3 0-12.8 10.4-23.3 23.3-23.3h851c12.9 0 23.3 10.4 23.3 23.3-.1 12.9-10.5 23.3-23.3 23.3z",
      "fill": "#2c2c2c"
    }
  }), _c("path", {
    attrs: {
      "d": "M363.4 957.3c-12.9 0-23.3-10.4-23.3-23.3V315.8c0-12.8 10.4-23.3 23.3-23.3s23.3 10.4 23.3 23.3V934c0 12.9-10.4 23.3-23.3 23.3zm299.2 0c-12.9 0-23.3-10.4-23.3-23.3V315.8c0-12.8 10.4-23.3 23.3-23.3s23.3 10.4 23.3 23.3V934c0 12.9-10.5 23.3-23.3 23.3z",
      "fill": "#2c2c2c"
    }
  })]);
};
var RichTextTable = {
  render
};
var IconRichTextTable = svg({
  name: "IconRichTextTable",
  component: RichTextTable
});
export {
  IconRichTextTable as default
};

==> vue-icon-saas-2.22.2.tgz: package/lib/rich-text-table.js <==
import { svg } from "@opentinyvue/vue-common";
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("svg", _vm._g({
    attrs: {
      "viewBox": "0 0 1024 1024",
      "xmlns": "http://www.w3.org/2000/svg"
    }
  }, _vm.$listeners), [_c("path", {
    attrs: {
      "d": "M885.3 957.3H140.7c-42.2 0-76.5-34.3-76.5-76.5V136.3c0-42.2 34.3-76.5 76.5-76.5h744.6c42.2 0 76.5 34.3 76.5 76.5v744.6c-.1 42.1-34.3 76.4-76.5 76.4zm-744.6-851c-16.5 0-29.9 13.4-29.9 29.9v744.6c0 16.5 13.4 29.9 29.9 29.9h744.6c16.5 0 29.9-13.4 29.9-29.9V136.3c0-16.5-13.4-29.9-29.9-29.9H140.7z",
      "fill": "#2c2c2c"
    }
  }), _c("path", {
    attrs: {
      "d": "M938.5 315.8h-851V91.1c0-4.4 3.6-8 8-8h835c4.4 0 8 3.6 8 8v224.7z",
      "fill": "#2c2c2c"
    }
  }), _c("path", {
    attrs: {
      "d": "M961.7 339H64.3V136.3c0-42.2 34.3-76.5 76.5-76.5h744.6c42.2 0 76.5 34.3 76.5 76.5V339zm-850.9-46.5h804.4V136.3c0-16.5-13.4-29.9-29.9-29.9H140.7c-16.5 0-29.9 13.4-29.9 29.9v156.2zm827.7 352.3h-851c-12.9 0-23.3-10.4-23.3-23.3 0-12.8 10.4-23.3 23.3-23.3h851c12.9 0 23.3 10.4 23.3 23.3-.1 12.9-10.5 23.3-23.3 23.3z",
      "fill": "#2c2c2c"
    }
  }), _c("path", {
    attrs: {
      "d": "M363.4 957.3c-12.9 0-23.3-10.4-23.3-23.3V315.8c0-12.8 10.4-23.3 23.3-23.3s23.3 10.4 23.3 23.3V934c0 12.9-10.4 23.3-23.3 23.3zm299.2 0c-12.9 0-23.3-10.4-23.3-23.3V315.8c0-12.8 10.4-23.3 23.3-23.3s23.3 10.4 23.3 23.3V934c0 12.9-10.5 23.3-23.3 23.3z",
      "fill": "#2c2c2c"
    }
  })]);
};
var RichTextTable = {
  render
};
var index = svg({
  name: "IconRichTextTable",
  component: RichTextTable
});
export {
  index as default
};
